@@ -336,7 +336,9 @@ create_bits_picture (PicturePtr pict,
     
     fbGetDrawable (drawable, bits, stride, bpp, xoff, yoff);
 
-    bits = (FbBits*)((CARD8*)bits + drawable->y * stride * sizeof(FbBits) + drawable->x * (bpp / 8));
+    bits = (FbBits*)((CARD8*)bits +
+		     (drawable->y + yoff) * stride * sizeof(FbBits) +
+		     (drawable->x + xoff) * (bpp / 8));
 
     image = pixman_image_create_bits (
 	pict->format, drawable->width, drawable->height,
